@@ -63,42 +63,43 @@ test_that("find_permuted_perf_metric works", {
   )
 })
 
-feat_imp <- structure(list(
-  perf_metric = c(
-    0.629157894736842, 0.605473684210526,
-    0.63878947368421, 0.636763157894737, 0.629447368421053, 0.637868421052632,
-    0.642552631578947, 0.592157894736842, 0.639684210526316, 0.637526315789474
+feat_imp <- structure(
+  list(
+    perf_metric = c(
+      0.629157894736842, 0.605473684210526,
+      0.63878947368421, 0.636763157894737, 0.629447368421053, 0.637868421052632,
+      0.642552631578947, 0.592157894736842, 0.639684210526316, 0.637526315789474
+    ),
+    perf_metric_diff = c(
+      0.0182105263157895, 0.0418947368421053,
+      0.00857894736842113, 0.0106052631578948, 0.0179210526315789,
+      0.00950000000000006, 0.00481578947368422, 0.0552105263157895,
+      0.00768421052631585, 0.00984210526315787
+    ),
+    pvalue = c(
+      0.238, 0.099,
+      0.188, 0.376, 0.386, 0.356, 0.287, 0.118, 0.218, 0.436
+    ),
+    names = structure(1:10, .Label = c(
+      "Otu00001",
+      "Otu00002", "Otu00003", "Otu00004", "Otu00005", "Otu00006", "Otu00007",
+      "Otu00008", "Otu00009", "Otu00010"
+    ), class = "factor"),
+    method = c(
+      "glmnet",
+      "glmnet", "glmnet", "glmnet", "glmnet", "glmnet", "glmnet", "glmnet",
+      "glmnet", "glmnet"
+    ),
+    perf_metric_name = c(
+      "AUC", "AUC", "AUC",
+      "AUC", "AUC", "AUC", "AUC", "AUC", "AUC", "AUC"
+    ),
+    seed = c(
+      2019,
+      2019, 2019, 2019, 2019, 2019, 2019, 2019, 2019, 2019
+    )
   ),
-  perf_metric_diff = c(
-    0.0182105263157895, 0.0418947368421053,
-    0.00857894736842113, 0.0106052631578948, 0.0179210526315789,
-    0.00950000000000006, 0.00481578947368422, 0.0552105263157895,
-    0.00768421052631585, 0.00984210526315787
-  ),
-  pvalue = c(
-    0.238, 0.099,
-    0.188, 0.376, 0.386, 0.356, 0.287, 0.118, 0.218, 0.436
-  ),
-  names = structure(1:10, .Label = c(
-    "Otu00001",
-    "Otu00002", "Otu00003", "Otu00004", "Otu00005", "Otu00006", "Otu00007",
-    "Otu00008", "Otu00009", "Otu00010"
-  ), class = "factor"),
-  method = c(
-    "glmnet",
-    "glmnet", "glmnet", "glmnet", "glmnet", "glmnet", "glmnet", "glmnet",
-    "glmnet", "glmnet"
-  ),
-  perf_metric_name = c(
-    "AUC", "AUC", "AUC",
-    "AUC", "AUC", "AUC", "AUC", "AUC", "AUC", "AUC"
-  ),
-  seed = c(
-    2019,
-    2019, 2019, 2019, 2019, 2019, 2019, 2019, 2019, 2019
-  )
-),
-row.names = c(NA, -10L), class = "data.frame"
+  row.names = c(NA, -10L), class = "data.frame"
 )
 
 test_that("feature importances are correct", {
@@ -107,8 +108,6 @@ test_that("feature importances are correct", {
   expect_equal(
     get_feature_importance(
       otu_mini_bin_results_glmnet$trained_model,
-      otu_mini_bin_results_glmnet$trained_model$trainingData %>%
-        dplyr::rename(dx = .outcome),
       otu_mini_bin_results_glmnet$test_data,
       "dx",
       caret::multiClassSummary,
@@ -128,8 +127,6 @@ test_that("feature importances are correct when tibbles used", {
   expect_equal(
     get_feature_importance(
       otu_mini_bin_results_glmnet$trained_model,
-      otu_mini_bin_results_glmnet$trained_model$trainingData %>%
-        dplyr::rename(dx = .outcome),
       otu_mini_bin_results_glmnet$test_data %>%
         dplyr::as_tibble(),
       "dx",
@@ -157,8 +154,6 @@ test_that("custom grouped features works", {
   expect_equal(
     get_feature_importance(
       otu_mini_bin_results_glmnet$trained_model,
-      otu_mini_bin_results_glmnet$trained_model$trainingData %>%
-        dplyr::rename(dx = .outcome),
       otu_mini_bin_results_glmnet$test_data %>%
         dplyr::as_tibble(),
       "dx",
